'use strict';

var _vueTestUtils = require('vue-test-utils');

var _deepAssign = require('deep-assign');

var _deepAssign2 = _interopRequireDefault(_deepAssign);

var _lodash = require('lodash.clonedeep');

var _lodash2 = _interopRequireDefault(_lodash);

var _index = require('../index');

var _index2 = _interopRequireDefault(_index);

var _vueServerRenderer = require('vue-server-renderer');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var options = {
  propsData: {
    color: 'primary',
    mode: 'ios'
  },
  slots: {
    default: '<span>Test</span>'
  }
};

describe('Badge', function () {
  it('@base: renders the correct markup', function () {
    var opts = (0, _deepAssign2.default)((0, _lodash2.default)(options), {
      propsData: {
        mode: 'md'
      }
    });
    var wrapper = (0, _vueTestUtils.mount)(_index2.default, opts);
    var result = '<div class="ion-badge badge badge-md badge-md-primary"><span>Test</span></div>';
    expect(wrapper.html()).toEqual(result);
  });

  it('@base: renders the correct text', function () {
    var opts = (0, _deepAssign2.default)((0, _lodash2.default)(options), {
      slots: {
        default: '<span>Test</span>'
      }
    });
    var wrapper = (0, _vueTestUtils.mount)(_index2.default, opts);
    expect(wrapper.text()).toEqual('Test');
  });

  it('@base: component must have a name', function () {
    var opts = (0, _deepAssign2.default)((0, _lodash2.default)(options), {
      slots: {
        default: '<span>Name</span>'
      }
    });
    var wrapper = (0, _vueTestUtils.mount)(_index2.default, opts);
    expect(wrapper.name()).toEqual('Badge');
  });

  it('@base: have the right className', function () {
    var opts = (0, _deepAssign2.default)((0, _lodash2.default)(options), {
      slots: {
        default: '<span>HasClass</span>'
      }
    });
    var wrapper = (0, _vueTestUtils.mount)(_index2.default, opts);
    expect(wrapper.hasClass('ion-badge')).toBeTruthy();
  });

  it('@base: matches snapshot', function () {
    var renderer = (0, _vueServerRenderer.createRenderer)();
    var wrapper = (0, _vueTestUtils.mount)(_index2.default, options);
    renderer.renderToString(wrapper.vm, function (err, str) {
      if (err) throw new Error(err);
      expect(str).toMatchSnapshot();
    });
  });

  it('@props: color', function () {
    var opts = (0, _deepAssign2.default)((0, _lodash2.default)(options), {
      propsData: {
        color: 'danger',
        mode: 'md'
      },
      slots: {
        default: '<span>color</span>'
      }
    });
    var wrapper = (0, _vueTestUtils.mount)(_index2.default, opts);
    expect(wrapper.hasClass('badge-md-danger')).toBeTruthy();
  });

  it('@props: mode', function () {
    var opts = (0, _deepAssign2.default)((0, _lodash2.default)(options), {
      propsData: {
        mode: 'md'
      },
      slots: {
        default: '<span>mode</span>'
      }
    });
    var wrapper = (0, _vueTestUtils.mount)(_index2.default, opts);
    expect(wrapper.hasClass('badge-md')).toBeTruthy();
  });

  it('@props: mode(default)', function () {
    var wrapper = (0, _vueTestUtils.mount)(_index2.default);
    expect(wrapper.hasClass('badge-ios')).toBeTruthy();
  });
});