'use strict';

var _vueTestUtils = require('vue-test-utils');

var _index = require('../index');

var _index2 = _interopRequireDefault(_index);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var options = {
  slots: {
    default: '<span>Test</span>'
  }
};

describe('Footer', function () {
  it('@base: renders the correct markup', function () {
    var wrapper = (0, _vueTestUtils.mount)(_index2.default, options);
    var result = '<footer class="ion-footer footer-ios"><span>Test</span></footer>';
    expect(wrapper.html().trim()).toEqual(result);
  });

  it('@base: renders the correct text', function () {
    var wrapper = (0, _vueTestUtils.mount)(_index2.default, options);
    expect(wrapper.text().trim()).toEqual('Test');
  });

  it('@base: component must have a name', function () {
    var wrapper = (0, _vueTestUtils.mount)(_index2.default, options);
    expect(wrapper.name()).toEqual('Footer');
  });

  it('@base: have the right className', function () {
    var wrapper = (0, _vueTestUtils.mount)(_index2.default, options);
    expect(wrapper.hasClass('ion-footer')).toBeTruthy();
  });

  it('hide()', function () {
    var wrapper = (0, _vueTestUtils.mount)(_index2.default);
    wrapper.vm.hide();
    expect(wrapper.vm.isHide).toBeTruthy();
  });

  it('show()', function () {
    var wrapper = (0, _vueTestUtils.mount)(_index2.default);
    wrapper.vm.show();
    expect(wrapper.vm.isHide).toBeFalsy();
  });

  it('toggle()', function () {
    var wrapper = (0, _vueTestUtils.mount)(_index2.default);
    var isHide = !wrapper.vm.isHide;
    wrapper.vm.toggle();
    expect(wrapper.vm.isHide).toEqual(isHide);
  });

  it('setStyle()', function (cb) {
    var wrapper = (0, _vueTestUtils.mount)(_index2.default);
    wrapper.vm.setStyle({
      color: '#EEEEEE'
    });
    setTimeout(function () {
      expect(wrapper.hasStyle('color', '#EEEEEE')).toBeTruthy();
      cb();
    }, 100);
  });
});