'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

exports.getProps = getProps;
exports.getEvents = getEvents;
function getProps() {
  var defaults = {
    direction: 'horizontal',
    touchEventsTarget: 'container',
    initialSlide: 0,
    speed: 300,

    autoplay: false,
    autoplayDisableOnInteraction: true,
    autoplayStopOnLast: false,

    iOSEdgeSwipeDetection: false,
    iOSEdgeSwipeThreshold: 20,

    freeMode: false,
    freeModeMomentum: true,
    freeModeMomentumRatio: 1,
    freeModeMomentumBounce: true,
    freeModeMomentumBounceRatio: 1,
    freeModeMomentumVelocityRatio: 1,
    freeModeSticky: false,
    freeModeMinimumVelocity: 0.02,

    autoHeight: false,

    setWrapperSize: false,

    virtualTranslate: false,

    effect: 'slide',
    coverflow: {
      rotate: 50,
      stretch: 0,
      depth: 100,
      modifier: 1,
      slideShadows: true
    },
    flip: {
      slideShadows: true,
      limitRotation: true
    },
    cube: {
      slideShadows: true,
      shadow: true,
      shadowOffset: 20,
      shadowScale: 0.94
    },
    fade: {
      crossFade: false
    },

    parallax: false,

    zoom: false,
    zoomMax: 3,
    zoomMin: 1,
    zoomToggle: true,

    scrollbar: null,
    scrollbarHide: true,
    scrollbarDraggable: false,
    scrollbarSnapOnRelease: false,

    keyboardControl: false,
    mousewheelControl: false,
    mousewheelReleaseOnEdges: false,
    mousewheelInvert: false,
    mousewheelForceToAxis: false,
    mousewheelSensitivity: 1,
    mousewheelEventsTarged: 'container',

    hashnav: false,
    hashnavWatchState: false,

    history: false,

    replaceState: false,

    breakpoints: undefined,

    spaceBetween: 0,
    slidesPerView: 1,
    slidesPerColumn: 1,
    slidesPerColumnFill: 'column',
    slidesPerGroup: 1,
    centeredSlides: false,
    slidesOffsetBefore: 0,
    slidesOffsetAfter: 0,
    roundLengths: false,

    touchRatio: 1,
    touchAngle: 45,
    simulateTouch: true,
    shortSwipes: true,
    longSwipes: true,
    longSwipesRatio: 0.5,
    longSwipesMs: 300,
    followFinger: true,
    onlyExternal: false,
    threshold: 0,
    touchMoveStopPropagation: true,
    touchReleaseOnEdges: false,

    uniqueNavElements: true,

    pagination: null,
    paginationElement: 'span',
    paginationClickable: false,
    paginationHide: false,
    paginationBulletRender: null,
    paginationProgressRender: null,
    paginationFractionRender: null,
    paginationCustomRender: null,
    paginationType: 'bullets',
    resistance: true,
    resistanceRatio: 0.85,

    nextButton: null,
    prevButton: null,

    watchSlidesProgress: false,
    watchSlidesVisibility: false,

    grabCursor: false,

    preventClicks: true,
    preventClicksPropagation: true,
    slideToClickedSlide: false,

    lazyLoading: false,
    lazyLoadingInPrevNext: false,
    lazyLoadingInPrevNextAmount: 1,
    lazyLoadingOnTransitionStart: false,

    preloadImages: true,
    updateOnImagesReady: true,

    loop: false,
    loopAdditionalSlides: 0,
    loopedSlides: null,

    control: undefined,
    controlInverse: false,
    controlBy: 'slide',
    normalizeSlideIndex: true,

    allowSwipeToPrev: true,
    allowSwipeToNext: true,
    swipeHandler: null,
    noSwiping: true,
    noSwipingClass: 'swiper-no-swiping',

    passiveListeners: true,

    containerModifierClass: 'swiper-container-',
    slideClass: 'swiper-slide',
    slideActiveClass: 'swiper-slide-active',
    slideDuplicateActiveClass: 'swiper-slide-duplicate-active',
    slideVisibleClass: 'swiper-slide-visible',
    slideDuplicateClass: 'swiper-slide-duplicate',
    slideNextClass: 'swiper-slide-next',
    slideDuplicateNextClass: 'swiper-slide-duplicate-next',
    slidePrevClass: 'swiper-slide-prev',
    slideDuplicatePrevClass: 'swiper-slide-duplicate-prev',
    wrapperClass: 'swiper-wrapper',
    bulletClass: 'swiper-pagination-bullet',
    bulletActiveClass: 'swiper-pagination-bullet-active',
    buttonDisabledClass: 'swiper-button-disabled',
    paginationCurrentClass: 'swiper-pagination-current',
    paginationTotalClass: 'swiper-pagination-total',
    paginationHiddenClass: 'swiper-pagination-hidden',
    paginationProgressbarClass: 'swiper-pagination-progressbar',
    paginationClickableClass: 'swiper-pagination-clickable',
    paginationModifierClass: 'swiper-pagination-',
    lazyLoadingClass: 'swiper-lazy',
    lazyStatusLoadingClass: 'swiper-lazy-loading',
    lazyStatusLoadedClass: 'swiper-lazy-loaded',
    lazyPreloaderClass: 'swiper-lazy-preloader',
    notificationClass: 'swiper-notification',
    preloaderClass: 'preloader',
    zoomContainerClass: 'swiper-zoom-container',

    observer: false,
    observeParents: false,

    a11y: false,
    prevSlideMessage: 'Previous slide',
    nextSlideMessage: 'Next slide',
    firstSlideMessage: 'This is the first slide',
    lastSlideMessage: 'This is the last slide',
    paginationBulletMessage: 'Go to slide {{index}}',

    runCallbacksOnInit: true
  };
  var props = {};

  var _loop = function _loop(key) {
    var value = defaults[key];
    var valueType = typeof value === 'undefined' ? 'undefined' : _typeof(value);
    var tmp = null;
    switch (valueType) {
      case 'number':
        tmp = {
          type: [Number, String],
          default: value
        };
        break;
      case 'string':
        tmp = {
          type: String,
          default: value
        };
        break;
      case 'boolean':
        tmp = {
          type: [Boolean, Number],
          default: value
        };
        break;
      case 'object':
        if (value) {
          tmp = {
            type: Object,
            default: function _default() {
              return JSON.parse(JSON.stringify(value));
            }
          };
        } else {
          tmp = {
            type: [Object, Number, String, Function, Array],
            default: function _default() {
              return null;
            }
          };
        }
        break;
      case 'function':
        tmp = {
          type: Function,
          default: function _default() {
            return value;
          }
        };
        break;
      case 'undefined':
        tmp = [Object];
        break;
      default:
        tmp = [Object];
        console.debug('这个属性未找到::interface.js::getProps()');
        console.debug('key: ' + key);
        console.debug('value: ' + value);
        console.debug('valueType: ' + valueType);
        break;
    }
    props[key] = tmp;
  };

  for (var key in defaults) {
    _loop(key);
  }
  return props;
}

function getEvents(slideComponent) {
  console.assert(slideComponent, 'The method of getEvents() need params of slideComponent!');
  return {
    onInit: function onInit(swiper) {
      slideComponent.$emit('onInit', swiper);
    },
    onDestroy: function onDestroy(swiper) {
      slideComponent.$emit('onDestroy', swiper);
    },
    onBeforeResize: function onBeforeResize(swiper) {
      slideComponent.$emit('onBeforeResize', swiper);
    },
    onAfterResize: function onAfterResize(swiper) {
      slideComponent.$emit('onAfterResize', swiper);
    },
    onClick: function onClick(swiper, e) {
      slideComponent.$emit('onClick', swiper, e);
    },
    onTap: function onTap(swiper, e) {
      slideComponent.$emit('onTap', swiper, e);
    },
    onDoubleTap: function onDoubleTap(swiper, e) {
      slideComponent.$emit('onDoubleTap', swiper, e);
    },
    onSliderMove: function onSliderMove(swiper, e) {
      slideComponent.$emit('onSliderMove', swiper, e);
    },
    onSlideChangeStart: function onSlideChangeStart(swiper) {
      slideComponent.$emit('onSlideChangeStart', swiper);
    },
    onSlideChangeEnd: function onSlideChangeEnd(swiper) {
      slideComponent.$emit('onSlideChangeEnd', swiper);
    },
    onTransitionStart: function onTransitionStart(swiper) {
      slideComponent.$emit('onTransitionStart', swiper);
    },
    onTransitionEnd: function onTransitionEnd(swiper) {
      slideComponent.$emit('onTransitionEnd', swiper);
    },
    onImagesReady: function onImagesReady(swiper) {
      slideComponent.$emit('onImagesReady', swiper);
    },
    onProgress: function onProgress(swiper, progress) {
      slideComponent.$emit('onProgress', swiper, progress);
    },
    onTouchStart: function onTouchStart(swiper, e) {
      slideComponent.$emit('onTouchStart', swiper, e);
    },
    onTouchMove: function onTouchMove(swiper, e) {
      slideComponent.$emit('onTouchMove', swiper, e);
    },
    onTouchMoveOpposite: function onTouchMoveOpposite(swiper, e) {
      slideComponent.$emit('onTouchMoveOpposite', swiper, e);
    },
    onTouchEnd: function onTouchEnd(swiper, e) {
      slideComponent.$emit('onTouchEnd', swiper, e);
    },
    onReachBeginning: function onReachBeginning(swiper) {
      slideComponent.$emit('onReachBeginning', swiper);
    },
    onReachEnd: function onReachEnd(swiper) {
      slideComponent.$emit('onReachEnd', swiper);
    },
    onSetTransition: function onSetTransition(swiper, duration) {
      slideComponent.$emit('onSetTransition', swiper, duration);
    },
    onSetTranslate: function onSetTranslate(swiper, translate) {
      slideComponent.$emit('onSetTranslate', swiper, translate);
    },
    onAutoplayStart: function onAutoplayStart(swiper) {
      slideComponent.$emit('onAutoplayStart', swiper);
    },
    onAutoplayStop: function onAutoplayStop(swiper) {
      slideComponent.$emit('onAutoplayStop', swiper);
    },
    onLazyImageLoad: function onLazyImageLoad(swiper, slide, image) {
      slideComponent.$emit('onLazyImageLoad', swiper, slide, image);
    },
    onLazyImageReady: function onLazyImageReady(swiper, slide, image) {
      slideComponent.$emit('onLazyImageReady', swiper, slide, image);
    },
    onKeyPress: function onKeyPress(swiper, keyCode) {
      slideComponent.$emit('onKeyPress', swiper, keyCode);
    }
  };
}